@@ -1,30 +1,30 @@
-( cd lib ; rm -rf cpp )
-( cd lib ; ln -sf /usr/bin/cpp cpp )
-( cd usr/bin ; rm -rf cc )
-( cd usr/bin ; ln -sf gcc cc )
-( cd usr/bin ; rm -rf gcc )
-( cd usr/bin ; ln -sf gcc-4.1.2 gcc )
-( cd usr/bin ; rm -rf i486-slackware-linux-gcc-4.1.2 )
-( cd usr/bin ; ln -sf gcc-4.1.2 i486-slackware-linux-gcc-4.1.2 )
-( cd usr/bin ; rm -rf i486-slackware-linux-gcc )
-( cd usr/bin ; ln -sf gcc-4.1.2 i486-slackware-linux-gcc )
-( cd usr/lib ; rm -rf libssp.so )
-( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so )
+( cd usr/lib ; rm -rf libgcc_s.so )
+( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
 ( cd usr/lib ; rm -rf libmudflap.so.0 )
 ( cd usr/lib ; ln -sf libmudflap.so.0.0.0 libmudflap.so.0 )
+( cd usr/lib ; rm -rf libmudflap.so )
+( cd usr/lib ; ln -sf libmudflap.so.0.0.0 libmudflap.so )
 ( cd usr/lib ; rm -rf libmudflapth.so.0 )
 ( cd usr/lib ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so.0 )
 ( cd usr/lib ; rm -rf libmudflapth.so )
 ( cd usr/lib ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so )
 ( cd usr/lib ; rm -rf libssp.so.0 )
 ( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so.0 )
-( cd usr/lib ; rm -rf libgcc_s.so )
-( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
-( cd usr/lib/classpath ; rm -rf libgjsmalsa.so.0 )
-( cd usr/lib/classpath ; ln -sf libgjsmalsa.so.0.0.0 libgjsmalsa.so.0 )
-( cd usr/lib/classpath ; rm -rf libgjsmalsa.so )
-( cd usr/lib/classpath ; ln -sf libgjsmalsa.so.0.0.0 libgjsmalsa.so )
-( cd usr/lib ; rm -rf libmudflap.so )
-( cd usr/lib ; ln -sf libmudflap.so.0.0.0 libmudflap.so )
+( cd usr/lib ; rm -rf libssp.so )
+( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so )
+( cd usr/lib ; rm -rf libgomp.so.1 )
+( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so.1 )
+( cd usr/lib ; rm -rf libgomp.so )
+( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so )
+( cd usr/bin ; rm -rf gcc )
+( cd usr/bin ; ln -sf gcc-4.2.3 gcc )
+( cd usr/bin ; rm -rf cc )
+( cd usr/bin ; ln -sf gcc cc )
+( cd usr/bin ; rm -rf i486-slackware-linux-gcc-4.2.3 )
+( cd usr/bin ; ln -sf gcc-4.2.3 i486-slackware-linux-gcc-4.2.3 )
+( cd usr/bin ; rm -rf i486-slackware-linux-gcc )
+( cd usr/bin ; ln -sf gcc-4.2.3 i486-slackware-linux-gcc )
 ( cd usr/man/man1 ; rm -rf cc.1.gz )
 ( cd usr/man/man1 ; ln -sf gcc.1.gz cc.1.gz )
+( cd lib ; rm -rf cpp )
+( cd lib ; ln -sf /usr/bin/cpp cpp )
